==> zio-aws-alexaforbusiness_3-5.17.155.2-sources.jar: zio/aws/alexaforbusiness/model/ProfileData.scala <==
package zio.aws.alexaforbusiness.model
import zio.ZIO
import zio.aws.alexaforbusiness.model.primitives.{
  Arn,
  DeviceLocale,
  ProfileName,
  Address,
  Timezone
}
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class ProfileData(
    profileArn: Option[Arn] = None,
    profileName: Option[ProfileName] = None,
    isDefault: Option[Boolean] = None,
    address: Option[Address] = None,
    timezone: Option[Timezone] = None,
    distanceUnit: Option[zio.aws.alexaforbusiness.model.DistanceUnit] = None,
    temperatureUnit: Option[zio.aws.alexaforbusiness.model.TemperatureUnit] =
      None,
    wakeWord: Option[zio.aws.alexaforbusiness.model.WakeWord] = None,
    locale: Option[DeviceLocale] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.alexaforbusiness.model.ProfileData = {
    import ProfileData.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.alexaforbusiness.model.ProfileData
      .builder()
      .optionallyWith(
        profileArn.map(value => Arn.unwrap(value): java.lang.String)
      )(_.profileArn)
      .optionallyWith(
        profileName.map(value => ProfileName.unwrap(value): java.lang.String)
      )(_.profileName)
      .optionallyWith(isDefault.map(value => value: java.lang.Boolean))(
        _.isDefault
      )
      .optionallyWith(
        address.map(value => Address.unwrap(value): java.lang.String)
      )(_.address)
      .optionallyWith(
        timezone.map(value => Timezone.unwrap(value): java.lang.String)
      )(_.timezone)
      .optionallyWith(distanceUnit.map(value => value.unwrap))(_.distanceUnit)
      .optionallyWith(temperatureUnit.map(value => value.unwrap))(
        _.temperatureUnit
      )
      .optionallyWith(wakeWord.map(value => value.unwrap))(_.wakeWord)
      .optionallyWith(
        locale.map(value => DeviceLocale.unwrap(value): java.lang.String)
      )(_.locale)
      .build()
  }
  def asReadOnly: zio.aws.alexaforbusiness.model.ProfileData.ReadOnly =
    zio.aws.alexaforbusiness.model.ProfileData.wrap(buildAwsValue())
}
object ProfileData {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.alexaforbusiness.model.ProfileData
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.alexaforbusiness.model.ProfileData =
      zio.aws.alexaforbusiness.model.ProfileData(
        profileArn.map(value => value),
        profileName.map(value => value),
        isDefault.map(value => value),
        address.map(value => value),
        timezone.map(value => value),
        distanceUnit.map(value => value),
        temperatureUnit.map(value => value),
        wakeWord.map(value => value),
        locale.map(value => value)
      )
    def profileArn: Option[Arn]
    def profileName: Option[ProfileName]
    def isDefault: Option[Boolean]
    def address: Option[Address]
    def timezone: Option[Timezone]
    def distanceUnit: Option[zio.aws.alexaforbusiness.model.DistanceUnit]
    def temperatureUnit: Option[zio.aws.alexaforbusiness.model.TemperatureUnit]
    def wakeWord: Option[zio.aws.alexaforbusiness.model.WakeWord]
    def locale: Option[DeviceLocale]
    def getProfileArn: ZIO[Any, AwsError, Arn] =
      AwsError.unwrapOptionField("profileArn", profileArn)
    def getProfileName: ZIO[Any, AwsError, ProfileName] =
      AwsError.unwrapOptionField("profileName", profileName)
    def getIsDefault: ZIO[Any, AwsError, Boolean] =
      AwsError.unwrapOptionField("isDefault", isDefault)
    def getAddress: ZIO[Any, AwsError, Address] =
      AwsError.unwrapOptionField("address", address)
    def getTimezone: ZIO[Any, AwsError, Timezone] =
      AwsError.unwrapOptionField("timezone", timezone)
    def getDistanceUnit
        : ZIO[Any, AwsError, zio.aws.alexaforbusiness.model.DistanceUnit] =
      AwsError.unwrapOptionField("distanceUnit", distanceUnit)
    def getTemperatureUnit
        : ZIO[Any, AwsError, zio.aws.alexaforbusiness.model.TemperatureUnit] =
      AwsError.unwrapOptionField("temperatureUnit", temperatureUnit)
    def getWakeWord
        : ZIO[Any, AwsError, zio.aws.alexaforbusiness.model.WakeWord] =
      AwsError.unwrapOptionField("wakeWord", wakeWord)
    def getLocale: ZIO[Any, AwsError, DeviceLocale] =
      AwsError.unwrapOptionField("locale", locale)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.alexaforbusiness.model.ProfileData
  ) extends zio.aws.alexaforbusiness.model.ProfileData.ReadOnly {
    override val profileArn: Option[Arn] = scala
      .Option(impl.profileArn())
      .map(value => zio.aws.alexaforbusiness.model.primitives.Arn(value))
    override val profileName: Option[ProfileName] = scala
      .Option(impl.profileName())
      .map(value =>
        zio.aws.alexaforbusiness.model.primitives.ProfileName(value)
      )
    override val isDefault: Option[Boolean] =
      scala.Option(impl.isDefault()).map(value => value: Boolean)
    override val address: Option[Address] = scala
      .Option(impl.address())
      .map(value => zio.aws.alexaforbusiness.model.primitives.Address(value))
    override val timezone: Option[Timezone] = scala
      .Option(impl.timezone())
      .map(value => zio.aws.alexaforbusiness.model.primitives.Timezone(value))
    override val distanceUnit
        : Option[zio.aws.alexaforbusiness.model.DistanceUnit] = scala
      .Option(impl.distanceUnit())
      .map(value => zio.aws.alexaforbusiness.model.DistanceUnit.wrap(value))
    override val temperatureUnit
        : Option[zio.aws.alexaforbusiness.model.TemperatureUnit] = scala
      .Option(impl.temperatureUnit())
      .map(value => zio.aws.alexaforbusiness.model.TemperatureUnit.wrap(value))
    override val wakeWord: Option[zio.aws.alexaforbusiness.model.WakeWord] =
      scala
        .Option(impl.wakeWord())
        .map(value => zio.aws.alexaforbusiness.model.WakeWord.wrap(value))
    override val locale: Option[DeviceLocale] = scala
      .Option(impl.locale())
      .map(value =>
        zio.aws.alexaforbusiness.model.primitives.DeviceLocale(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.alexaforbusiness.model.ProfileData
  ): zio.aws.alexaforbusiness.model.ProfileData.ReadOnly = new Wrapper(impl)
}

==> zio-aws-alexaforbusiness_3-5.17.211.1-sources.jar: zio/aws/alexaforbusiness/model/ProfileData.scala <==
package zio.aws.alexaforbusiness.model
import zio.ZIO
import zio.aws.alexaforbusiness.model.primitives.{
  Arn,
  DeviceLocale,
  ProfileName,
  Address,
  Timezone
}
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters.*
final case class ProfileData(
    profileArn: Optional[Arn] = Optional.Absent,
    profileName: Optional[ProfileName] = Optional.Absent,
    isDefault: Optional[Boolean] = Optional.Absent,
    address: Optional[Address] = Optional.Absent,
    timezone: Optional[Timezone] = Optional.Absent,
    distanceUnit: Optional[zio.aws.alexaforbusiness.model.DistanceUnit] =
      Optional.Absent,
    temperatureUnit: Optional[zio.aws.alexaforbusiness.model.TemperatureUnit] =
      Optional.Absent,
    wakeWord: Optional[zio.aws.alexaforbusiness.model.WakeWord] =
      Optional.Absent,
    locale: Optional[DeviceLocale] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.alexaforbusiness.model.ProfileData = {
    import ProfileData.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.alexaforbusiness.model.ProfileData
      .builder()
      .optionallyWith(
        profileArn.map(value => Arn.unwrap(value): java.lang.String)
      )(_.profileArn)
      .optionallyWith(
        profileName.map(value => ProfileName.unwrap(value): java.lang.String)
      )(_.profileName)
      .optionallyWith(isDefault.map(value => value: java.lang.Boolean))(
        _.isDefault
      )
      .optionallyWith(
        address.map(value => Address.unwrap(value): java.lang.String)
      )(_.address)
      .optionallyWith(
        timezone.map(value => Timezone.unwrap(value): java.lang.String)
      )(_.timezone)
      .optionallyWith(distanceUnit.map(value => value.unwrap))(_.distanceUnit)
      .optionallyWith(temperatureUnit.map(value => value.unwrap))(
        _.temperatureUnit
      )
      .optionallyWith(wakeWord.map(value => value.unwrap))(_.wakeWord)
      .optionallyWith(
        locale.map(value => DeviceLocale.unwrap(value): java.lang.String)
      )(_.locale)
      .build()
  }
  def asReadOnly: zio.aws.alexaforbusiness.model.ProfileData.ReadOnly =
    zio.aws.alexaforbusiness.model.ProfileData.wrap(buildAwsValue())
}
object ProfileData {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.alexaforbusiness.model.ProfileData
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.alexaforbusiness.model.ProfileData =
      zio.aws.alexaforbusiness.model.ProfileData(
        profileArn.map(value => value),
        profileName.map(value => value),
        isDefault.map(value => value),
        address.map(value => value),
        timezone.map(value => value),
        distanceUnit.map(value => value),
        temperatureUnit.map(value => value),
        wakeWord.map(value => value),
        locale.map(value => value)
      )
    def profileArn: Optional[Arn]
    def profileName: Optional[ProfileName]
    def isDefault: Optional[Boolean]
    def address: Optional[Address]
    def timezone: Optional[Timezone]
    def distanceUnit: Optional[zio.aws.alexaforbusiness.model.DistanceUnit]
    def temperatureUnit
        : Optional[zio.aws.alexaforbusiness.model.TemperatureUnit]
    def wakeWord: Optional[zio.aws.alexaforbusiness.model.WakeWord]
    def locale: Optional[DeviceLocale]
    def getProfileArn: ZIO[Any, AwsError, Arn] =
      AwsError.unwrapOptionField("profileArn", profileArn)
    def getProfileName: ZIO[Any, AwsError, ProfileName] =
      AwsError.unwrapOptionField("profileName", profileName)
    def getIsDefault: ZIO[Any, AwsError, Boolean] =
      AwsError.unwrapOptionField("isDefault", isDefault)
    def getAddress: ZIO[Any, AwsError, Address] =
      AwsError.unwrapOptionField("address", address)
    def getTimezone: ZIO[Any, AwsError, Timezone] =
      AwsError.unwrapOptionField("timezone", timezone)
    def getDistanceUnit
        : ZIO[Any, AwsError, zio.aws.alexaforbusiness.model.DistanceUnit] =
      AwsError.unwrapOptionField("distanceUnit", distanceUnit)
    def getTemperatureUnit
        : ZIO[Any, AwsError, zio.aws.alexaforbusiness.model.TemperatureUnit] =
      AwsError.unwrapOptionField("temperatureUnit", temperatureUnit)
    def getWakeWord
        : ZIO[Any, AwsError, zio.aws.alexaforbusiness.model.WakeWord] =
      AwsError.unwrapOptionField("wakeWord", wakeWord)
    def getLocale: ZIO[Any, AwsError, DeviceLocale] =
      AwsError.unwrapOptionField("locale", locale)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.alexaforbusiness.model.ProfileData
  ) extends zio.aws.alexaforbusiness.model.ProfileData.ReadOnly {
    override val profileArn: Optional[Arn] = zio.aws.core.internal
      .optionalFromNullable(impl.profileArn())
      .map(value => zio.aws.alexaforbusiness.model.primitives.Arn(value))
    override val profileName: Optional[ProfileName] = zio.aws.core.internal
      .optionalFromNullable(impl.profileName())
      .map(value =>
        zio.aws.alexaforbusiness.model.primitives.ProfileName(value)
      )
    override val isDefault: Optional[Boolean] = zio.aws.core.internal
      .optionalFromNullable(impl.isDefault())
      .map(value => value: Boolean)
    override val address: Optional[Address] = zio.aws.core.internal
      .optionalFromNullable(impl.address())
      .map(value => zio.aws.alexaforbusiness.model.primitives.Address(value))
    override val timezone: Optional[Timezone] = zio.aws.core.internal
      .optionalFromNullable(impl.timezone())
      .map(value => zio.aws.alexaforbusiness.model.primitives.Timezone(value))
    override val distanceUnit
        : Optional[zio.aws.alexaforbusiness.model.DistanceUnit] =
      zio.aws.core.internal
        .optionalFromNullable(impl.distanceUnit())
        .map(value => zio.aws.alexaforbusiness.model.DistanceUnit.wrap(value))
    override val temperatureUnit
        : Optional[zio.aws.alexaforbusiness.model.TemperatureUnit] =
      zio.aws.core.internal
        .optionalFromNullable(impl.temperatureUnit())
        .map(value =>
          zio.aws.alexaforbusiness.model.TemperatureUnit.wrap(value)
        )
    override val wakeWord: Optional[zio.aws.alexaforbusiness.model.WakeWord] =
      zio.aws.core.internal
        .optionalFromNullable(impl.wakeWord())
        .map(value => zio.aws.alexaforbusiness.model.WakeWord.wrap(value))
    override val locale: Optional[DeviceLocale] = zio.aws.core.internal
      .optionalFromNullable(impl.locale())
      .map(value =>
        zio.aws.alexaforbusiness.model.primitives.DeviceLocale(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.alexaforbusiness.model.ProfileData
  ): zio.aws.alexaforbusiness.model.ProfileData.ReadOnly = new Wrapper(impl)
}
